@@ -7,9 +7,9 @@
 #' The tuning parameter is chosen using the Extended Bayesian Information criterium
 #' (EBIC) described by Foygel & Drton (2010).
 #'
-#' @param S A covariance or correlation matrix
+#' @param data Data matrix
 #'
-#' @param n Sample size used in computing \code{S}
+#' @param n Number of participants
 #'
 #' @param gamma EBIC tuning parameter. 0.5 is generally a good choice.
 #' Setting to zero will cause regular BIC to be used.
@@ -23,12 +23,6 @@
 #' @param returnAllResults   If \code{TRUE} this function does not
 #' return a network but the results of the entire glasso path.
 #'
-#' @param checkPD
-#' If \code{TRUE}, the function will check if \code{S} is positive definite
-#' and return an error if not. It is not advised to use a
-#' non-positive definite matrix as input as (a) that can not
-#' be a covariance matrix and (b) glasso can hang if the input is not positive definite.
-#'
 #' @param penalizeMatrix Optional logical matrix to indicate which elements are penalized
 #'
 #' @param countDiagonal     Should diagonal be counted in EBIC computation?
@@ -92,25 +86,24 @@
 #'
 #' # Compute graph with tuning = 0.5 (EBIC)
 #' EBICgraph <- EBICglasso.qgraph(CorMat, nrow(wmt2), 0.5)
-#' 
+#'
 #' }
 #'
 #' @export
 #'
 # Computes optimal glasso network based on EBIC:
 EBICglasso.qgraph <- function(
-  S, # Sample covariance matrix
-  n, # Sample size
-  gamma = 0.5,
-  penalize.diagonal = FALSE, # Penalize diagonal?
-  nlambda = 100,
-  lambda.min.ratio = 0.01,
-  returnAllResults = FALSE, # If true, returns a list
-  checkPD = TRUE, # Checks if matrix is positive definite and stops if not
-  penalizeMatrix, # Optional logical matrix to indicate which elements are penalized
-  countDiagonal = FALSE, # Set to TRUE to get old qgraph behavior: conting diagonal elements as parameters in EBIC computation. This is not correct, but is included to replicate older analyses
-  refit = FALSE, # If TRUE, network structure is taken and non-penalized version is computed.
-  ... # glasso arguments
+    data, # Sample covariance matrix
+    n = NULL,
+    gamma = 0.5,
+    penalize.diagonal = FALSE, # Penalize diagonal?
+    nlambda = 100,
+    lambda.min.ratio = 0.01,
+    returnAllResults = FALSE, # If true, returns a list
+    penalizeMatrix, # Optional logical matrix to indicate which elements are penalized
+    countDiagonal = FALSE, # Set to TRUE to get old qgraph behavior: conting diagonal elements as parameters in EBIC computation. This is not correct, but is included to replicate older analyses
+    refit = FALSE, # If TRUE, network structure is taken and non-penalized version is computed.
+    ... # glasso arguments
 ) {
 
     # Codes originally implemented by Sacha Epskamp in his qgraph package version 1.4.4.
@@ -158,87 +151,95 @@ EBICglasso.qgraph <- function(
         return(x)
     }
 
-  if (checkPD){
-    if (any(eigen(S)$values < 0)) stop("'S' is not positive definite")
-  }
+    if(is.null(n))
+    {
+        if(nrow(data)!=ncol(data))
+        {n <- nrow(data)
+        }else{stop("Number of participants 'n' need to be specified")}
+    }
 
-  # Standardize cov matrix:
-  S <- stats::cov2cor(S)
+    # Compute correlations matrix
+    if(nrow(data)!=ncol(data))
+    {S <- qgraph::cor_auto(data)
+    }else{
+      S <- data
+    }
 
-  # Compute lambda sequence (code taken from huge package):
-  lambda.max = max(max(S - diag(nrow(S))), -min(S - diag(nrow(S))))
-  lambda.min = lambda.min.ratio*lambda.max
-  lambda = exp(seq(log(lambda.min), log(lambda.max), length = nlambda))
+    # Compute lambda sequence (code taken from huge package):
+    lambda.max = max(max(S - diag(nrow(S))), -min(S - diag(nrow(S))))
+    lambda.min = lambda.min.ratio*lambda.max
+    lambda = exp(seq(log(lambda.min), log(lambda.max), length = nlambda))
 
-  # Run glasso path:
-  if (missing(penalizeMatrix)){
-    glas_path <- glasso::glassopath(S, lambda, trace = 0, penalize.diagonal=penalize.diagonal, ...)
-  }else{
-    glas_path <- list(
-      w = array(0, c(ncol(S), ncol(S), length(lambda))),
-      wi = array(0, c(ncol(S), ncol(S), length(lambda))),
-      rholist = lambda
-    )
+    # Run glasso path:
+    if (missing(penalizeMatrix)){
+        glas_path <- glasso::glassopath(S, lambda, trace = 0, penalize.diagonal=penalize.diagonal, ...)
+    }else{
+        glas_path <- list(
+            w = array(0, c(ncol(S), ncol(S), length(lambda))),
+            wi = array(0, c(ncol(S), ncol(S), length(lambda))),
+            rholist = lambda
+        )
 
-    for (i in 1:nlambda){
-      res <- glasso::glasso(S, penalizeMatrix * lambda[i], trace = 0, penalize.diagonal=penalize.diagonal, ...)
-      glas_path$w[,,i] <- res$w
-      glas_path$wi[,,i] <- res$wi
+        for (i in 1:nlambda){
+            res <- glasso::glasso(S, penalizeMatrix * lambda[i], trace = 0, penalize.diagonal=penalize.diagonal, ...)
+            glas_path$w[,,i] <- res$w
+            glas_path$wi[,,i] <- res$wi
+        }
     }
-  }
 
 
-  # Compute EBICs:
-  #     EBICs <- apply(glas_path$wi,3,function(C){
-  #       EBIC(S, C, n, gamma)
-  #     })
+    # Compute EBICs:
+    #     EBICs <- apply(glas_path$wi,3,function(C){
+    #       EBIC(S, C, n, gamma)
+    #     })
 
-  lik <- sapply(seq_along(lambda),function(i){
-    logGaus(S, glas_path$wi[,,i], n)
-  })
+    lik <- sapply(seq_along(lambda),function(i){
+        logGaus(S, glas_path$wi[,,i], n)
+    })
 
-  EBICs <- sapply(seq_along(lambda),function(i){
-    EBIC(S, glas_path$wi[,,i], n, gamma, countDiagonal=countDiagonal)
-  })
+    EBICs <- sapply(seq_along(lambda),function(i){
+        EBIC(S, glas_path$wi[,,i], n, gamma, countDiagonal=countDiagonal)
+    })
 
-  # Smallest EBIC:
-  opt <- which.min(EBICs)
+    # Smallest EBIC:
+    opt <- which.min(EBICs)
 
-  # Check if rho is smallest:
-  #if (opt == 1){
-  #  warning("Network with lowest lambda selected as best network. Try setting 'lambda.min.ratio' lower.")
-  #}
+    # Check if rho is smallest:
+    #if (opt == 1){
+    #  warning("Network with lowest lambda selected as best network. Try setting 'lambda.min.ratio' lower.")
+    #}
 
-  # Return network:
-  net <- as.matrix(Matrix::forceSymmetric(wi2net(glas_path$wi[,,opt])))
-  colnames(net) <- rownames(net) <- colnames(S)
-
-  # Check empty network:
-  if (all(net == 0)){
-    message("An empty network was selected to be the best fitting network. Possibly set 'lambda.min.ratio' higher to search more sparse networks. You can also change the 'gamma' parameter to improve sensitivity (at the cost of specificity).")
-  }
-
-  # Refit network:
-  # Refit:
-  if (refit){
-    message("Refitting network without LASSO regularization")
-    glassoRes <- suppressWarnings(glasso::glasso(S, 0, zero = which(net == 0 & upper.tri(net), arr.ind=TRUE), trace = 0, penalize.diagonal=penalize.diagonal, ...))
-    net <- as.matrix(Matrix::forceSymmetric(wi2net(glassoRes$wi)))
+    # Return network:
+    net <- as.matrix(Matrix::forceSymmetric(wi2net(glas_path$wi[,,opt])))
     colnames(net) <- rownames(net) <- colnames(S)
-    optwi <- glassoRes$wi
-  } else {
-    optwi <- glas_path$wi[,,opt]
-  }
 
-  # Return
-  if (returnAllResults){
-    return(list(
-      results = glas_path,
-      ebic = EBICs,
-      loglik = lik,
-      optnet = net,
-      lambda = lambda,
-      optwi = optwi
-    ))
-  } else return(net)
+    # Check empty network:
+    if (all(net == 0)){
+        message("An empty network was selected to be the best fitting network. Possibly set 'lambda.min.ratio' higher to search more sparse networks. You can also change the 'gamma' parameter to improve sensitivity (at the cost of specificity).")
+    }
+
+    # Refit network:
+    # Refit:
+    if (refit){
+        message("Refitting network without LASSO regularization")
+        glassoRes <- suppressWarnings(glasso::glasso(S, 0, zero = which(net == 0 & upper.tri(net), arr.ind=TRUE), trace = 0, penalize.diagonal=penalize.diagonal, ...))
+        net <- as.matrix(Matrix::forceSymmetric(wi2net(glassoRes$wi)))
+        colnames(net) <- rownames(net) <- colnames(S)
+        optwi <- glassoRes$wi
+    } else {
+        optwi <- glas_path$wi[,,opt]
+    }
+
+    # Return
+    if (returnAllResults){
+        return(list(
+            results = glas_path,
+            ebic = EBICs,
+            loglik = lik,
+            optnet = net,
+            lambda = lambda,
+            optwi = optwi
+        ))
+    } else return(net)
 }
+#----
