@@ -3,7 +3,7 @@
 #' @description Computes the fit (TEFI) of a dimensionality structure using Von Neumman's entropy when the input is a correlation matrix.
 #' Lower values suggest better fit of a structure to the data.
 #'
-#' @param data A dataset or a correlation matrix
+#' @param data A dataframe or correlation matrix
 #'
 #' @param structure A vector representing the structure (numbers or labels for each item).
 #' Can be theoretical factors or the structure detected by \code{\link{EGA}}
@@ -27,7 +27,7 @@
 #' }
 #'
 #' # Compute entropy indices
-#' tefi(data = wmt, structure = ega.wmt$wc)
+#' tefi(data = ega.wmt$correlation, structure = ega.wmt$wc)
 #'
 #' @seealso \code{\link[EGAnet]{EGA}} to estimate the number of dimensions of an instrument using EGA and
 #' \code{\link[EGAnet]{CFA}} to verify the fit of the structure suggested by EGA using confirmatory factor analysis.
@@ -37,22 +37,10 @@
 #' @export
 # Total Entropy Fit Index Function (for correlation matrices)
 tefi <- function(data, structure){
-  if(!is.matrix(data)){
-    cor1 <- qgraph::cor_auto(data)/ncol(data)
-    h.vn <- -matrixcalc::matrix.trace(cor1%*%log(cor1))
-
-    n <- max(structure)
-    cor.fact <- vector("list")
-    eigen.fact <- vector("list")
-    l.eigen.fact <- vector("list")
-    h.vn.fact <- vector("list")
-    for(i in 1:n){
-      cor.fact[[i]] <- qgraph::cor_auto(data[,which(structure==unique(structure)[i])])
-      cor.fact[[i]] <- cor.fact[[i]]/ncol(cor.fact[[i]])
-      h.vn.fact[[i]] <- -matrixcalc::matrix.trace(cor.fact[[i]]%*%log(cor.fact[[i]]))
-    }
-
-  } else{
+  if(!ncol(data)==nrow(data)){
+    data <- qgraph::cor_auto(data)
+  }
+    data <- abs(data)
     cor1 <- data/ncol(data)
     h.vn <- -matrixcalc::matrix.trace(cor1%*%(log(cor1)))
 
@@ -66,7 +54,6 @@ tefi <- function(data, structure){
       cor.fact[[i]] <- cor.fact[[i]]/ncol(cor.fact[[i]])
       h.vn.fact[[i]] <- -matrixcalc::matrix.trace(cor.fact[[i]]%*%log(cor.fact[[i]]))
     }
-  }
 
   h.vn.fact2 <- unlist(h.vn.fact)
 
